@@ -10,8 +10,8 @@
 #include "sessionuiproxy.h"
 
 #include <QApplication>
-#include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QCommandLineParser>
 
 #include <KIO/SslUi>
 
@@ -36,16 +36,14 @@ void login(KSmtp::Session *session, const QString &user, const QString &pass, bo
     } else if (starttls) {
         login->setEncryptionMode(KSmtp::LoginJob::STARTTLS);
     }
-    QObject::connect(
-        login, &KJob::result,
-        [](KJob *job) {
-            if (job->error()) {
-                std::cout << "Login error: " << job->errorString().toStdString() << std::endl;
-                qApp->quit();
-            } else {
-                std::cout << "Login job finished" << std::endl;
-            }
-        });
+    QObject::connect(login, &KJob::result, [](KJob *job) {
+        if (job->error()) {
+            std::cout << "Login error: " << job->errorString().toStdString() << std::endl;
+            qApp->quit();
+        } else {
+            std::cout << "Login job finished" << std::endl;
+        }
+    });
     login->start();
     std::cout << "Login job started" << std::endl;
 }
@@ -71,48 +69,43 @@ int main(int argc, char **argv)
 
     parser.process(app);
 
-    if (!parser.isSet(hostOption) || !parser.isSet(portOption)
-        || !parser.isSet(userOption) || !parser.isSet(passOption)) {
+    if (!parser.isSet(hostOption) || !parser.isSet(portOption) || !parser.isSet(userOption) || !parser.isSet(passOption)) {
         parser.showHelp(1);
         return 1;
     }
 
-    KSmtp::Session session(parser.value(hostOption),
-                           parser.value(portOption).toUInt());
+    KSmtp::Session session(parser.value(hostOption), parser.value(portOption).toUInt());
     session.setUiProxy(SessionUiProxy::Ptr(new SessionUiProxy));
-    QObject::connect(
-        &session, &KSmtp::Session::stateChanged,
-        [&](KSmtp::Session::State state) {
-            switch (state) {
-            case KSmtp::Session::Disconnected:
-                std::cout << "Session in Disconnected state" << std::endl;
-                break;
-            case KSmtp::Session::Handshake:
-                std::cout << "Session in Handshake state" << std::endl;
-                break;
-            case KSmtp::Session::Ready:
-                std::cout << "Session in Ready state" << std::endl;
-                std::cout << std::endl;
-                login(&session, parser.value(userOption), parser.value(passOption),
-                      parser.isSet(sslTlsOption), parser.isSet(startTlsOption));
-                break;
-            case KSmtp::Session::Quitting:
-                //Internal (avoid compile warning)
-                break;
-            case KSmtp::Session::NotAuthenticated: {
-                std::cout << "Session in NotAuthenticated state" << std::endl;
-                std::cout << "Available auth modes: ";
-                const auto modes = session.availableAuthModes();
-                for (const QString &mode : modes) {
-                    std::cout << mode.toStdString() << " ";
-                }
-                std::cout << std::endl;
-            } break;
-            case KSmtp::Session::Authenticated:
-                std::cout << "Session entered Authenticated state, we are done" << std::endl;
-                app.quit();
+    QObject::connect(&session, &KSmtp::Session::stateChanged, [&](KSmtp::Session::State state) {
+        switch (state) {
+        case KSmtp::Session::Disconnected:
+            std::cout << "Session in Disconnected state" << std::endl;
+            break;
+        case KSmtp::Session::Handshake:
+            std::cout << "Session in Handshake state" << std::endl;
+            break;
+        case KSmtp::Session::Ready:
+            std::cout << "Session in Ready state" << std::endl;
+            std::cout << std::endl;
+            login(&session, parser.value(userOption), parser.value(passOption), parser.isSet(sslTlsOption), parser.isSet(startTlsOption));
+            break;
+        case KSmtp::Session::Quitting:
+            // Internal (avoid compile warning)
+            break;
+        case KSmtp::Session::NotAuthenticated: {
+            std::cout << "Session in NotAuthenticated state" << std::endl;
+            std::cout << "Available auth modes: ";
+            const auto modes = session.availableAuthModes();
+            for (const QString &mode : modes) {
+                std::cout << mode.toStdString() << " ";
             }
-        });
+            std::cout << std::endl;
+        } break;
+        case KSmtp::Session::Authenticated:
+            std::cout << "Session entered Authenticated state, we are done" << std::endl;
+            app.quit();
+        }
+    });
     std::cout << "Opening session ..." << std::endl;
     session.open();
 
